@@ -326,3 +326,13 @@ PsychError PsychModuleInit(void)
 
     return(PsychError_none);
 }
+
+#if PSYCH_LANGUAGE == PSYCH_PYTHON
+
+PyMODINIT_FUNC
+initScreen(void)
+{
+    PsychPythonInit("Screen");
+}
+
+#endif
