@@ -28,6 +28,66 @@
 #if PSYCH_SYSTEM == PSYCH_OSX
 // Need these includes to make setting display brightness work:
 #include <IOKit/graphics/IOGraphicsLib.h>
+# include <ApplicationServices/ApplicationServices.h>
+
+/*
+    The code for using System private interfaces (SPI's) for getting/setting display
+    brightness on Apple's trainwreck operating system was adapted from the code of
+    Nicholas Riley at https://github.com/nriley/brightness which is licensed under
+    the following BSD-2 clause license (Thank you!):
+
+    Copyright (c) 2014-2019, Nicholas Riley
+    All rights reserved.
+
+    Redistribution and use in source and binary forms, with or without modification,
+    are permitted provided that the following conditions are met:
+
+    * Redistributions of source code must retain the above copyright notice, this
+    list of conditions and the following disclaimer.
+
+    * Redistributions in binary form must reproduce the above copyright notice, this
+    list of conditions and the following disclaimer in the documentation and/or
+    other materials provided with the distribution.
+
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+    ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
+    ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+/* As of macOS 10.12.4, brightness set by public IOKit API is
+ overridden by CoreDisplay's brightness (to support Night Shift). In
+ addition, using CoreDisplay to get brightness supports additional
+ display types, e.g. the 2015 iMac's internal display.
+ The below functions in CoreDisplay seem to work to adjust the
+ "user" brightness (like dragging the slider in System Preferences
+ or using function keys).  The symbols below are listed in the .tbd
+ file in CoreDisplay.framework so it is at least more "public" than
+ a symbol in a private framework, though there are no public headers
+ distributed for this framework. */
+extern double CoreDisplay_Display_GetUserBrightness(CGDirectDisplayID id) __attribute__((weak_import));
+extern void CoreDisplay_Display_SetUserBrightness(CGDirectDisplayID id, double brightness) __attribute__((weak_import));
+
+/*  Some issues with the above CoreDisplay functions include:
+     - There's no way to tell if setting the brightness was successful
+     - There's no way to tell if a brightness of 1 means that the
+     brightness is actually 1, or if there's no adjustable brightness
+     - Brightness changes aren't reflected in System Preferences
+     immediately
+     Fixing these means using the private DisplayServices.framework.  Be
+     even more careful about these.
+ */
+extern _Bool DisplayServicesCanChangeBrightness(CGDirectDisplayID id) __attribute__((weak_import));
+extern void DisplayServicesBrightnessChanged(CGDirectDisplayID id, double brightness) __attribute__((weak_import));
+
+/* Also try to get a handle on AutoBrightness switch function: */
+extern void CoreDisplay_Display_SetAutoBrightnessIsEnabled(CGDirectDisplayID id, bool enable) __attribute__((weak_import));
 #endif
 
 const char *FieldNames[]={"width", "height", "pixelSize", "hz"};
@@ -44,6 +104,15 @@ PsychError SCREENConfigureDisplay(void)
                     " The function will either return a >= brightness value, or -1 if the system doesn't support brightness control. "
                     " If you try to set brightness on a system that doesn't support it, the function will abort with an error. "
                     " Brightness values are in the range 0.0 to 1.0 from darkest to brightest. Returns old brightness setting.\n"
+                    "'AutoBrightnessMode': Set the AutoBrightness mode on supported systems, macOS only at the moment. "
+                    "If you call the function without specifying a new mode, it will return -1 if setting AutoBrightness is "
+                    "unsupported on the system, otherwise it will return the value 2 to confirm setting AutoBrightness should be possible.\n"
+                    "If you try to set AutoBrightness on a system that doesn't support it, the function will abort with an error. "
+                    "Otherwise it will return 2 to confirm it tried to set AutoBrightness mode and then try to set the mode you "
+                    "specified: A mode of 1 tries to enable AutoBrightness, a mode of 0 tries to disable AutoBrightness on the given output. "
+                    "Please note that there isn't any feedback if switching AutoBrightness worked, or what the current or previous enable "
+                    "state of AutoBrightness is or was, as queries are not supported by macOS. Neither will there be reliable visual feedback "
+                    "in the macOS display settings GUI! This feature is experimental and may not work at any time for any reason!\n"
                     "'NumberOutputs': Return number of active separate display outputs for given screen 'screenNumber'.\n"
                     "'Capture': Capture output 'outputId' of a screen 'screenNumber' for exclusive use by Psychtoolbox.\n"
                     "'Release': Release output 'outputId' of a screen 'screenNumber' from exclusive use by Psychtoolbox.\n"
@@ -99,6 +168,59 @@ PsychError SCREENConfigureDisplay(void)
     // Get name of parameter class:
     PsychAllocInCharArg(1, kPsychArgRequired, &settingName);
 
+    if (PsychMatch(settingName, "AutoBrightnessMode")) {
+        // OS/X specific section:
+        #if PSYCH_SYSTEM == PSYCH_OSX
+            CGDirectDisplayID displayID;
+            int autobrightnessMode;
+            outputId = -1;
+
+            // Get the screen number from the windowPtrOrScreenNumber. This also checks to make sure that the specified screen exists.
+            if (PsychCopyInScreenNumberArg(2, FALSE, &screenNumber)) {
+                if (screenNumber == -1) PsychErrorExitMsg(PsychError_user, "Invalid screen number.");
+                outputId = screenNumber;
+            }
+
+            // Get outputId:
+            PsychCopyInIntegerArg(3, FALSE, &outputId);
+            if (outputId < 0 || outputId >= kPsychMaxPossibleCrtcs) PsychErrorExitMsg(PsychError_user, "Invalid video output specified!");
+
+            PsychGetCGDisplayIDFromScreenNumber(&displayID, outputId);
+
+            // Return if setting autobrightness mode is supported: -1 for unsupported, 2 for supported.
+            PsychCopyOutDoubleArg(1, kPsychArgOptional, (CoreDisplay_Display_SetAutoBrightnessIsEnabled != NULL) ? 2 : -1);
+
+            // Optionally set new auto-brightness enable state:
+            if (PsychCopyInIntegerArg(4, FALSE, &autobrightnessMode)) {
+                if (autobrightnessMode < 0 || autobrightnessMode > 1)
+                    PsychErrorExitMsg(PsychError_user, "Invalid autobrightnessMode specified! Must be 0 for disable or 1 for enable.");
+
+                // Set it: Is the system private interface for this available?
+                if (CoreDisplay_Display_SetAutoBrightnessIsEnabled != NULL) {
+                    // Yes: Set new enable state. In god we trust, as there isn't any known way to query if we succeeded:
+                    CoreDisplay_Display_SetAutoBrightnessIsEnabled(displayID, (autobrightnessMode > 0) ? true : false);
+                }
+                else {
+                    // Nope: We fail.
+                    PsychErrorExitMsg(PsychError_user, "Failed to set new auto-brightness mode via SPI. Unsupported on this system.");
+                }
+            }
+
+            return(PsychError_none);
+        #else
+            // Unsupported on non-OSX atm. Return -1 for "not supported" if this was just a query,
+            // but fail if code tried to set a new value. This way a failure to change autobrightness
+            // won't go unnoticed, but code can query first if setting autobrightness is supported
+            // before it trusts results:
+            if (PsychIsArgPresent(PsychArgIn, 4))
+                PsychErrorExitMsg(PsychError_user, "Failed to change current display auto-brightness mode. Unsupported on this system.");
+            else
+                PsychCopyOutDoubleArg(1, kPsychArgOptional, -1);
+
+            return(PsychError_none);
+        #endif
+    }
+
     // Usercode wants to change display brightness:
     if (PsychMatch(settingName, "Brightness")) {
         // OS/X specific section:
@@ -123,17 +245,36 @@ PsychError SCREENConfigureDisplay(void)
         PsychGetCGDisplayIDFromScreenNumber(&displayID, outputId);
         io_service_t service = CGDisplayIOServicePort(displayID);
 
-        // Return current brightness value:
-        err = IODisplayGetFloatParameter(service, kNilOptions, CFSTR(kIODisplayBrightnessKey), &brightness);
-        if (err != kIOReturnSuccess) {
-            // Failed. This means "unsupported". Return -1 for "not supported" if this was just a query,
-            // but fail if code tried to set a new value. This way a failure to set a brightness level
-            // won't go unnoticed, but code can query first if setting/getting brightness is supported
-            // before it trusts results:
-            if (PsychIsArgPresent(PsychArgIn, 4))
-                PsychErrorExitMsg(PsychError_user, "Failed to query and set current display brightness from system. Unsupported on this system.");
-            else
-                brightness = -1;
+        // Return current brightness value: Prefer SPI (System private interface) for this,
+        // as it isn't as fucked up as Apple's public implementation:
+        if (CoreDisplay_Display_GetUserBrightness != NULL) {
+            // Query possible and meaningful?
+            if ((DisplayServicesCanChangeBrightness != NULL) && !DisplayServicesCanChangeBrightness(displayID)) {
+                // Nope. This means "unsupported". Return -1 for "not supported" if this was just a query,
+                // but fail if code tried to set a new value. This way a failure to set a brightness level
+                // won't go unnoticed, but code can query first if setting/getting brightness is supported
+                // before it trusts results:
+                if (PsychIsArgPresent(PsychArgIn, 4))
+                    PsychErrorExitMsg(PsychError_user, "Failed to query and set current display brightness from system via SPI. Unsupported on this system.");
+                else
+                    brightness = -1;
+            }
+
+            // Supported. Query it:
+            brightness = CoreDisplay_Display_GetUserBrightness(displayID);
+        }
+        else {
+            err = IODisplayGetFloatParameter(service, kNilOptions, CFSTR(kIODisplayBrightnessKey), &brightness);
+            if (err != kIOReturnSuccess) {
+                // Failed. This means "unsupported". Return -1 for "not supported" if this was just a query,
+                // but fail if code tried to set a new value. This way a failure to set a brightness level
+                // won't go unnoticed, but code can query first if setting/getting brightness is supported
+                // before it trusts results:
+                if (PsychIsArgPresent(PsychArgIn, 4))
+                    PsychErrorExitMsg(PsychError_user, "Failed to query and set current display brightness from system. Unsupported on this system.");
+                else
+                    brightness = -1;
+            }
         }
         PsychCopyOutDoubleArg(1, kPsychArgOptional, (double) brightness);
 
@@ -143,9 +284,24 @@ PsychError SCREENConfigureDisplay(void)
             if (nbrightness < 0.0) nbrightness = 0.0;
             if (nbrightness > 1.0) nbrightness = 1.0;
 
-            // Set it:
-            err = IODisplaySetFloatParameter(service, kNilOptions, CFSTR(kIODisplayBrightnessKey), (float) nbrightness);
-            if (err != kIOReturnSuccess) PsychErrorExitMsg(PsychError_user, "Failed to set new display brightness. Unsupported on this system?");
+            // Set it: Prefer SPI (System private interface) for this, as it isn't as fucked up as Apple's public implementation:
+            if (CoreDisplay_Display_SetUserBrightness != NULL) {
+                // Can brightness be changed on this system?
+                if ((DisplayServicesCanChangeBrightness != NULL) && !DisplayServicesCanChangeBrightness(displayID))
+                    PsychErrorExitMsg(PsychError_user, "Failed to set new display brightness via SPI. Unsupported on this system?");
+
+                // Set it:
+                CoreDisplay_Display_SetUserBrightness(displayID, nbrightness);
+
+                // Notify UI:
+                if (DisplayServicesBrightnessChanged != NULL)
+                    DisplayServicesBrightnessChanged(displayID, nbrightness);
+            }
+            else {
+                err = IODisplaySetFloatParameter(service, kNilOptions, CFSTR(kIODisplayBrightnessKey), (float) nbrightness);
+                if (err != kIOReturnSuccess)
+                    PsychErrorExitMsg(PsychError_user, "Failed to set new display brightness. Unsupported on this system?");
+            }
         }
         #endif
 
