@@ -19,7 +19,7 @@ function [fractionBleached] = ComputePhotopigmentBleaching(irradiance,receptorty
 % by the timeunits argument (default, msec).
 %
 % As far as I can tell, the fundemantal measurements of the half-bleach
-% constant for cones were made by Rushton and Henry (1968, Vision Reserch,
+% constant for human cones were made by Rushton and Henry (1968, Vision Research,
 % 8, 617-631). This fact I learned from CVRL
 % (http://www.cvrl.org/database/text/intros/introbleaches.htm).
 %
@@ -56,6 +56,16 @@ function [fractionBleached] = ComputePhotopigmentBleaching(irradiance,receptorty
 % two numbers are ballpark consistent with Rodiek page 475 who gives 18.3
 % and 15.9 for a monochromatic 540 THz light (555 nm)].
 %
+% This paper
+%   Burkhardt, D. A. "Light adaptation and photopigment
+%   bleaching in cone photoreceptors in situ in the retina
+%   of the turtle." Journal of Neuroscience 14.3 (1994):
+%   1091-1105.
+% provides a half bleach constant for turtle cones of 5.57 expressed
+% in log10 R*/um2/sec, which could with some work be converted to
+% isomerizations/cone/sec for turtle cones. But it's not
+% clear you want to use that number unless you are studying turtle.
+%
 % This routine will do the computation either on the basis of input in
 % trolands or input in isomerization/cone-sec, using the appropirate
 % constant as above.  Note that the computation of isomerizations takes
@@ -112,6 +122,13 @@ function [fractionBleached] = ComputePhotopigmentBleaching(irradiance,receptorty
 %               varying signal.  This breaks old usage that allowed
 %               computing steady state bleaching for a set of vector
 %               inputs, but I think that is OK.
+% 08/19/19 dhb  Added some information about Burkhardt (1994) to header
+%               comment, and inserted a stub to use that information if
+%               someone does the work to put the number from it into the
+%               right units.
+%          dhb  Reorganized some code relative to source switch statement. Because
+%               there was only one case this didn't matter, but now I think it
+%               is right if more cases.
 
 %% Specify receptor type
 if (nargin < 2 || isempty(receptortype))
@@ -123,7 +140,7 @@ if (nargin < 3 || isempty(units))
     units = 'trolands';
 end
 
-%% Specify source 
+%% Specify source
 if (nargin < 4 || isempty(source))
     source = 'Boynton';
 end
@@ -151,25 +168,37 @@ switch (receptortype)
                     otherwise
                         error('Unkown input units specified');
                 end
-                
-                % Steady state calculation
-                if (isempty(initialFraction))
-                    fractionBleached = (irradiance./(irradiance + Izero));
-                
-                % Time varying calculation.
-                else
-                    % Take timeunits into account.
-                    switch (timeunits)
-                        case 'msec'
-                            disp('Need to implement time varying calculation');
-                        otherwise
-                            error('Unknown time units specified');
-                    end
+                      
+            case 'Burkhardt'
+                switch (units)
+                    case 'trolands'
+                        error('Only know how to deal units in isomserization/sec for Burkhardt case');
+                    case 'isomerizations'
+                        error('You need to do some more work to put the Burkhardt number into the right units');
+                        %Izero = 10^5.57;
+                    otherwise
+                        error('Unkown input units specified');
                 end
                 
             otherwise
                 error('Unknown source specified');
         end
+        
+        % Steady state calculation
+        if (isempty(initialFraction))
+            fractionBleached = (irradiance./(irradiance + Izero));
+            
+        % Time varying calculation.
+        else
+            % Take timeunits into account.
+            switch (timeunits)
+                case 'msec'
+                    disp('Need to implement time varying calculation');
+                otherwise
+                    error('Unknown time units specified');
+            end
+        end
+        
     otherwise
         error('Unknown receptor type specified');
 end
