@@ -43,7 +43,9 @@ try
 
     screens=Screen('Screens');
     screenNumber=max(screens);
-    [w, rect] = Screen('OpenWindow', screenNumber, 0);
+    PsychImaging('PrepareConfiguration');
+    %PsychImaging('AddTask', 'General', 'UseRetinaResolution');
+    [w, rect] = PsychImaging('OpenWindow', screenNumber, 0);
 
     % Enable alpha blending with proper blend-function. We need it
     % for drawing of smoothed points:
@@ -159,8 +161,8 @@ try
     end;
 
     ShowCursor;
-    Screen('CloseAll');
+    sca;
 catch
     ShowCursor;
-    Screen('CloseAll');
+    sca;
 end
