@@ -595,7 +595,7 @@ glDisable(gltextarget);
 Screen('EndOpenGL', win);
 
 % Close onscreen window and release all other ressources:
-Screen('CloseAll');
+sca;
 
 % Well done!
 return
