@@ -174,8 +174,8 @@ try
         Screen('StopVideoCapture', grabber);
     end
     Screen('CloseVideoCapture', grabber);
-    Screen('CloseAll');
+    sca;
     avgfps = count / telapsed %#ok<NOPRT,NASGU>
 catch %#ok<CTCH>
-    Screen('CloseAll');
+    sca;
 end
