@@ -2,7 +2,7 @@
 % 
 % Lets see if we can tame Color++ mode.
 %
-% 8/8/04	dhb		Started it.
+% 8/8/04  dhb   Started it.
 
 % Generate pixel values
 highPixel = bitset(255,1,0);
@@ -28,13 +28,11 @@ theImage = [theImage1 theImage2];
 [m,n] = size(theImage);
 imageRect = [0 0 m n];
 fprintf('Showing image\n');
-[window,rect] = Screen(1,'OpenWindow',0,[],32);
+[window,rect] = Screen(1,'OpenWindow',0);
 identityClut = (0:255)'*ones(1,3);
 Screen(window,'SetClut',identityClut);
 
 Screen(window,'PutImage',theImage,[0 0 n m]);
 fprintf('Hit any character to continue\n');
-GetChar;
-Screen(window,'Close'); 	 
-
-	
+KbStrokeWait;
+Screen(window,'Close');
