@@ -9,16 +9,16 @@
 whichScreen=1;
 
 % Open window fill frame buffer with zeros
-[window,screenRect] = Screen(whichScreen,'OpenWindow',0,[],32);
+[window,screenRect] = Screen(whichScreen,'OpenWindow',0);
 SCREEN(window,'SetClut',(0:255)'*ones(1,3));
 
 % Put up an image at various intensities using r/g plane packing.
 % This uses the direct map features of the Mono++ mode.
 for colorval = round(linspace(0,2^14-1,20))
-	monoImage = BitsPlusPackMonoImage(colorval*ones(300,300));
-	fprintf('Image setting to value %g\n',colorval);
-	SCREEN(window,'PutImage',monoImage);
-	GetChar;
+  monoImage = BitsPlusPackMonoImage(colorval*ones(300,300));
+  fprintf('Image setting to value %g\n',colorval);
+  SCREEN(window,'PutImage',monoImage);
+  KbStrokeWait;
 end
 
 % Use BITS++ to set uniform lookup tables of increasing values.
@@ -28,10 +28,10 @@ theImage = zeros(300,300,3);
 theImage(:,:,3) = ones(300,300);
 SCREEN(window,'PutImage',theImage);
 for colorval = round(linspace(0,2^14-1,20))
-	uniclut = colorval*ones(256,3);
-	fprintf('Clut setting to value %g\n',colorval);
-	BitsPlusSetClut(window,uniclut);
-	GetChar;
+  uniclut = colorval*ones(256,3);
+  fprintf('Clut setting to value %g\n',colorval);
+  BitsPlusSetClut(window,uniclut);
+  KbStrokeWait;
 end
 
 % Close the window.
@@ -39,6 +39,3 @@ Screen(window,'Close');
 
 % Blank the screen
 BitsPlusBlank(whichScreen);
-
-
-
