@@ -595,9 +595,11 @@ if strcmpi(cmd, 'ResetOnWindowClose')
     % Reset videomode to pass-through:
     doDatapixx('SetVideoMode', 0);
 
-    % Set stereomode to "auto" and horizontal split to "auto":
-    doDatapixx('SetVideoHorizontalSplit', 2);
-    doDatapixx('SetVideoVerticalStereo', 2);
+    if doDatapixx('IsDatapixx')
+        % Set stereomode to "auto" and horizontal split to "auto":
+        doDatapixx('SetVideoHorizontalSplit', 2);
+        doDatapixx('SetVideoVerticalStereo', 2);
+    end
 
     % Disable Pixelsyncline:
     doDatapixx('SetVideoPixelSyncLine', 0, 0, 0);
@@ -917,15 +919,19 @@ end
 
 if strcmpi(cmd, 'SetVideoHorizontalSplit')
     % Set new horizontal split mode, apply immediately:
-    doDatapixx('SetVideoHorizontalSplit', varargin{1});
-    doDatapixx('RegWrRd');
+    if doDatapixx('IsDatapixx')
+        doDatapixx('SetVideoHorizontalSplit', varargin{1});
+        doDatapixx('RegWrRd');
+    end
     return;
 end
 
 if strcmpi(cmd, 'SetVideoVerticalStereo')
     % Set new vertical sync-doubling mode, apply immediately:
-    doDatapixx('SetVideoVerticalStereo', varargin{1});
-    doDatapixx('RegWrRd');
+    if doDatapixx('IsDatapixx')
+        doDatapixx('SetVideoVerticalStereo', varargin{1});
+        doDatapixx('RegWrRd');
+    end
     return;
 end
 
@@ -1019,7 +1025,7 @@ if strcmpi(cmd, 'PerformPostWindowOpenSetup')
 
     % Attach a postflip callback for things like timestamp and status
     % collection from the device after flip completion:
-    % Screen('Hookfunction', win, 'AppendMFunction', 'ScreenFlipImpliedOperations', 'Postflip callback into PsychDataPixx driver.', 'evalin(''base'', ''PsychDataPixx(2, IMAGINGPIPE_FLIPCOUNT);'');');
+    % Screen('Hookfunction', win, 'AppendMFunction', 'ScreenFlipImpliedOperations', 'Postflip callback into PsychDataPixx driver.', 'PsychDataPixx(2, IMAGINGPIPE_FLIPCOUNT);');
     Screen('Hookfunction', win, 'AppendMFunction', 'ScreenFlipImpliedOperations', 'Postflip callback into PsychDataPixx driver.', 'PsychDataPixx(2);');
     Screen('HookFunction', win, 'Enable', 'ScreenFlipImpliedOperations');
 
