@@ -1,6 +1,9 @@
 function varargout = PsychOculusVR(cmd, varargin)
 % PsychOculusVR - A high level driver for Oculus VR hardware.
 %
+% Oculus VR's trademarks, e.g., Oculus, Oculus Rift, etc. are registered trademarks
+% owned by Oculus VR, LLC.
+%
 % Note: If you want to write VR code that is portable across
 % VR headsets of different vendors, then use the PsychVRHMD()
 % driver instead of this driver. The PsychVRHMD driver will use
@@ -16,6 +19,14 @@ function varargout = PsychOculusVR(cmd, varargin)
 %
 % Usage:
 %
+% oldverbosity = PsychOculusVR('Verbosity' [, newverbosity]);
+% - Get/Set level of verbosity for driver status messages, warning messages,
+% error messages etc. 'newverbosity' is the optional new verbosity level,
+% 'oldverbosity' is the currently set verbosity level - ie. before changing
+% it.  Valid settings are: 0 = Silent, 1 = Errors only, 2 = Warnings, 3 = Info,
+% 4 = Debug.
+%
+%
 % hmd = PsychOculusVR('AutoSetupHMD' [, basicTask='Tracked3DVR'][, basicRequirements][, basicQuality=0][, deviceIndex]);
 % - Open a Oculus HMD, set it up with good default rendering and
 % display parameters and generate a PsychImaging('AddTask', ...)
@@ -166,7 +177,7 @@ function varargout = PsychOculusVR(cmd, varargin)
 % As this driver does not actually support special VR controllers, only a minimally
 % useful 'input' state is returned for compatibility with other drivers, which is
 % based on emulating or faking input from real controllers, so this function will be
-% of limited use. Specifically, only the input.Time and input.Buttons fields are
+% of limited use. Specifically, only the input.Valid, input.Time and input.Buttons fields are
 % returned, all other fields are missing. input.Buttons maps defined OVR.Button_XXX
 % fields to similar or corresponding buttons on the regular keyboard.
 %
@@ -177,6 +188,7 @@ function varargout = PsychOculusVR(cmd, varargin)
 % Return argument 'input' is a struct with fields describing the state of buttons and
 % other input elements of the specified 'controllerType'. It has the following fields:
 %
+% 'Valid' = 1 if 'input' contains valid results, 0 if input status is invalid/unavailable.
 % 'Time' Time of last input state change of controller.
 % 'Buttons' Vector with button state on the controller, similar to the 'keyCode'
 % vector returned by KbCheck() for regular keyboards. Each position in the vector
@@ -776,6 +788,8 @@ if strcmpi(cmd, 'GetInputState')
     error('PsychOculusVR:GetInputState: Required ''controllerType'' argument missing.');
   end
 
+  rc.Valid = 1;
+
   [anykey, rc.Time, keyCodes] = KbCheck(-1);
   rc.Buttons = zeros(1, 32);
   if anykey
